@@ -13,7 +13,7 @@ def _get_mailinglists_choices():
 class SubscribeForm(forms.Form):
     first_name = forms.CharField(label=_('First name'), required=False)
     last_name = forms.CharField(label=_('Last name'), required=False)
-    email = forms.EmailField(label=_('e-mail'), required=True)
+    email = forms.EmailField(label=_('E-mail'), required=True)
     mailing_lists = forms.MultipleChoiceField(
         label=_('Mailing lists'),
         initial=[0],
